# frozen_string_literal: true

require "commander"
require_relative "environments"

class ConfigureSentry
  ADMIN_EMAIL = "admin@renuo.ch"

  def run(args)
    project_name = args[0]
    sentry_dsn = args[1]
    abort(">> No project name given.") unless project_name
    abort(">> No sentry DSN name given.") unless sentry_dsn

    say "# Commands to setup Sentry on Heroku\n".colorize :green
    ENVIRONMENTS.each { |env| print_environment_commands(env, project_name, sentry_dsn) }
  end

  private

  def print_environment_commands(env, project_name, sentry_dsn)
    heroku_name = "#{project_name}-#{env}"
    say "heroku config:set SENTRY_DSN=#{sentry_dsn} --app #{heroku_name}"
    say "heroku config:set SENTRY_ENVIRONMENT=#{env} --app #{heroku_name}"
    say "heroku labs:enable runtime-dyno-metadata --app #{heroku_name}"
  end
end
