# frozen_string_literal: true

require_relative "command_helper"

class NameDisplay
  include CommandHelper

  def run(args, options)
    return open_path(SLIDES) if options.monitor
    return display_name(nil) if options.delete
    return say("empty argument") if args.empty?

    return run_heroku_command(args.join(" ")) if options.override

    display_name(args.join(" "))
  end

  private

  HEROKU_APP_NAME = "-a renuo-dashboard-main"
  HEROKU_CLI = "heroku run"
  RENUO_CLI = "rails renuo:welcome"
  SLIDES = "https://docs.google.com/presentation/d/1mPhQjArZnlUWUa2ik5R9IlGmdCKCwc2_H8Qq-AWgV-A/edit"
  WELCOME_MESSAGE = "Welcome to Renuo"

  def display_name(name)
    text_message = [WELCOME_MESSAGE, name, "🥳🔥"].compact.join(" ")
    run_heroku_command(text_message)
  end

  def run_heroku_command(text_message)
    rails_command = "\"#{RENUO_CLI}['#{text_message}']\""
    run_command([HEROKU_CLI, rails_command, HEROKU_APP_NAME].join(" "))
  end
end
